@@ -5,7 +5,7 @@ import os
 import plotly.graph_objs as go
 import numpy as np
 
-from chemdraw.drawers.drawer import Drawer, ConfigDrawer
+from chemdraw.drawers.drawer import Drawer, Config
 from chemdraw.objects.molecule import Molecule
 
 
@@ -13,7 +13,7 @@ class GridConfig:
 
     def __init__(self):
         # config
-        self.drawer_config: ConfigDrawer = ConfigDrawer()
+        self.drawer_config: Config = Config()
 
         # grid
         self.cell_width: int = 600
@@ -132,7 +132,7 @@ class GridDrawer:
                  molecules: list[str] | list[Molecule],
                  shape: tuple | list = None,  # [columns, rows]
                  config: GridConfig = None,
-                 config_drawer: list[ConfigDrawer] = None
+                 config_drawer: list[Config] = None
                  ):
         self.molecules = molecules
         self.config = config if config is not None else GridConfig()
@@ -153,13 +153,7 @@ class GridDrawer:
     def _get_shape(self, shape: tuple | list | None) -> tuple[int, int]:
         if shape is None:
             max_dim = int(np.ceil(np.sqrt(len(self.molecules))))
-            for i in range(max_dim-1):
-                if (len(self.molecules) % (max_dim + i)) == 0:
-                    max_dim = max_dim + i
-                    break
-
-            min_dim = int(len(self.molecules) / max_dim)
-            shape = np.array((max_dim, min_dim), dtype="int16")
+            shape = np.array((max_dim, max_dim), dtype="int16")
         else:
             if shape[0] * shape[1] < len(self.drawers):
                 raise ValueError(f"Shape must be a grid larger than need for the # of molecules.\n"
